@@ -1,4 +1,6 @@
-__version__ = '1.2.1'
+import pkg_resources
+
+__version__ = pkg_resources.get_distribution('pyramid_i18n_wrapper').version
 
 class LazyTranslationString:
     
