@@ -15,6 +15,9 @@ def wtforms_translation_string_factory(domain):
 
         def __mod__(self, data):
             return self.__str__() % data
+
+        def format(self, *args, **kargs):
+            return self.__str__().format(*args, **kargs)
     
     return _WTFormsLazyTranslationString
 
